@@ -85,7 +85,7 @@ picasa_http_write_cb (void *buffer,
 		      void *userp) {
 
 #ifdef DEBUG  
-  gchar *fn = "picasa_http_curl_callback()";
+  gchar *fn = "picasa_http_write_cb()";
 #endif
 
   http_request_t *request = (http_request_t*)userp;
