@@ -13,8 +13,10 @@
 
 
 /**
-   http_type_t
-*/
+ * http_type_t:
+ *
+ * HTTP reqeust type.
+ */
 typedef enum {
   POST = 0x01,
   GET = 0x02,
@@ -22,17 +24,32 @@ typedef enum {
 } http_type_t;
 
 /**
-   http_result_t
-*/
+ * http_result_t:
+ *
+ * HTTP function result codes.
+ */
 typedef enum {
   HTTP_SUCCESS,
   HTTP_ERROR
 } http_result_t;
 
+/**
+ * http_request_body_t:
+ * @data: Binary data
+ * @sent: How much sent already
+ *
+ * Binary data for read callback.
+ */
+typedef struct {
+  GString *data;
+  size_t sent;
+} picasa_http_body_t;
 
 /**
-   http_request_state_t
-*/
+ * http_request_state_t:
+ *
+ * HTTP request state.
+ */
 typedef enum {
   SENDING,
   DISCONNECTED,
@@ -41,46 +58,34 @@ typedef enum {
 } http_request_state_t;
 
 /**
-   picasa_http_body_t
+ * http_request_t:
+ * @state: Request state
+ * @url: Url where to post
+ * @hdr: Additional HTTP headers
+ * @post: CURL post data
+ * @last: CURL post data
+ * @buf_size_max: Response buffer max size
+ * @resp_buf: Pointer to response buffer
+ * @progress_cb: Pointer to progress callback function
+ * @progress_data: Pointer to progress data
+ * @con: Conic connection
+ * @read_data: Data for read callback
+ * @body_size: Size of request body
+ *
+ * HTTP request data structure.
 */
 typedef struct {
-  GString *data;
-  size_t sent;
-} picasa_http_body_t;
-
-/**
-   http_request_t
-*/
-typedef struct {
-
-  /* state of the request */
   http_request_state_t state;
-
-  /* where to send the request */
   gchar *url;
-
-  /* possible extra headers */
   struct curl_slist *hdr;
-
-  /* post fields for normal HTTP post */
   struct curl_httppost *post;
   struct curl_httppost *last;
-  
-  /* write buffer and its max size */
   size_t  buf_size_max;
   GString *resp_buf;  
-
-  /* curl progress callback and data */
   curl_progress_callback progress_cb;
   gpointer progress_data; 
-
-  /* conic connection handle */
   ConIcConnection *con;
-
-  /* possible read data */
   picasa_http_body_t read_data;
-
-  /* total http body size */
   size_t body_size;
 } http_request_t;
 
