@@ -8,11 +8,6 @@
 #ifndef _PICASA_XML_H_
 #define _PICASA_XML_H_
 
-#ifdef WITH_ALBUM_SUPPORT
-GSList*
-picasa_xml_parse_album_response (gchar *body);
-#endif /* WITH_ALBUM_SUPPORT */
-
 gchar*
 picasa_xml_parse_upload_response (gchar *body);
 
@@ -22,12 +17,6 @@ picasa_xml_parse_gps_response (gchar *body);
 gchar*
 picasa_xml_create_metadata_entry (gchar *title, gchar *summary);
 
-gchar*
-picasa_xml_create_tag_entry (gchar *tag);
-
-gchar*
-picasa_xml_create_gpstag_entry (gchar *tag);
-
 gchar*
 picasa_xml_create_media_entry (gchar *tags, gchar *gps);
 
